<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
  
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo gettext ("Logbook") ?></h1>
<p>
  <?php echo $this->date; ?>
  |
  <a href="?"><?php echo gettext ("today"); ?></a>
  |
  <a href="?day=1"><?php echo gettext ("yesterday"); ?></a>
  |
  <a href="?day=2"><?php echo gettext ("two days ago"); ?></a>
  |
  <a href="?day=3"><?php echo gettext ("three days ago"); ?></a>
</p>
<div id="logbook">
<?php  
foreach ($this->lines as $line) {
  echo "<p>$line</p>\n";
}
?>
</div>
<script>
<?php echo $this->script; ?>
</script>
<script type="text/javascript" src="logbook.js"></script>
